#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="lscr.io/linuxserver/prowlarr:develop"
}

do_install_detail() {
  local config=`uci get prowlarr.@prowlarr[0].config_path 2>/dev/null`
  local port=`uci get prowlarr.@prowlarr[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get prowlarr.@prowlarr[0].image_name 2>/dev/null`
  local username=`uci get prowlarr.@prowlarr[0].username 2>/dev/null`
  local password=`uci get prowlarr.@prowlarr[0].password 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=8160
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=lscr.io/linuxserver/prowlarr:develop

  
  # Create Docker Compose file with custom variables
   
  # Create Docker Compose file with custom variables
touch docker-compose.yml
cat > docker-compose.yml <<EOF
version: "2.1"
services:
  prowlarr:
    image: lscr.io/linuxserver/prowlarr:develop
    container_name: prowlarr
    environment:
      - PUID=1000
      - PGID=1000
      - TZ=Europe/London
    volumes:
      - ${config}:/config
    ports:
      - ${port}:9696
    restart: unless-stopped
    labels:
      plugsy.name: "prowlarr"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/simple-icons/Prowlarr"
      plugsy.link: "http://${LAN_IP}:${port}"
EOF
  
  docker-compose up -d
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install prowlarr"
  echo "      upgrade                Upgrade prowlarr"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart prowlarr"
  echo "      status                 prowlarr status"
  echo "      port                   prowlarr port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f prowlarr
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} prowlarr
  ;;
  "status")
    docker ps --all -f 'name=prowlarr' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=prowlarr' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
